@@ -119,10 +119,10 @@ function (y_true, y_pred, from_logits = FALSE, label_smoothing = 0,
     axis = -1L, ..., reduction = "sum_over_batch_size", name = "binary_crossentropy")
 {
     args <- capture_args(list(axis = as_axis, y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -331,10 +331,10 @@ function (y_true, y_pred, apply_class_balancing = FALSE,
     axis = -1L, ..., reduction = "sum_over_batch_size", name = "binary_focal_crossentropy")
 {
     args <- capture_args(list(axis = as_axis, y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -441,10 +441,10 @@ function (y_true, y_pred, from_logits = FALSE, label_smoothing = 0,
     axis = -1L, ..., reduction = "sum_over_batch_size", name = "categorical_crossentropy")
 {
     args <- capture_args(list(axis = as_axis, y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -598,10 +598,10 @@ function (y_true, y_pred, alpha = 0.25, gamma = 2,
     reduction = "sum_over_batch_size", name = "categorical_focal_crossentropy")
 {
     args <- capture_args(list(axis = as_axis, y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -663,10 +663,10 @@ function (y_true, y_pred, ..., reduction = "sum_over_batch_size",
     name = "categorical_hinge")
 {
     args <- capture_args(list(y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -736,10 +736,10 @@ function (y_true, y_pred, axis = -1L, ..., reduction = "sum_over_batch_size",
     name = "cosine_similarity")
 {
     args <- capture_args(list(axis = as_axis, y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -748,6 +748,53 @@ function (y_true, y_pred, axis = -1L, ..., reduction = "sum_over_batch_size",
     do.call(callable, args)
 }
 
+#' Computes the Dice loss value between `y_true` and `y_pred`.
+#'
+#' @description
+#' Formula:
+#' ```python
+#' loss = 1 - (2 * sum(y_true * y_pred)) / (sum(y_true) + sum(y_pred))
+#' ```
+#'
+#' Formula:
+#' ```python
+#' loss = 1 - (2 * sum(y_true * y_pred)) / (sum(y_true) + sum(y_pred))
+#' ```
+#'
+#' @returns
+#' if `y_true` and `y_pred` are provided, Dice loss value. Otherwise,
+#' a `Loss()` instance.
+#'
+#' @param y_true
+#' tensor of true targets.
+#'
+#' @param y_pred
+#' tensor of predicted targets.
+#'
+#' @param reduction
+#' Type of reduction to apply to the loss. In almost all cases
+#' this should be `"sum_over_batch_size"`.
+#' Supported options are `"sum"`, `"sum_over_batch_size"` or `NULL`.
+#'
+#' @param name
+#' String, name for the object
+#'
+#' @param ...
+#' For forward/backward compatability.
+#'
+#' @export
+#' @family losses
+#' @tether keras.losses.Dice
+loss_dice <-
+function (y_true, y_pred, ..., reduction = "sum_over_batch_size", name = "dice")
+{
+    args <- capture_args(list(y_true = as_py_array, y_pred = as_py_array))
+    callable <- if (missing(y_true) && missing(y_pred))
+        keras$losses$Dice
+    else keras$losses$dice
+    do.call(callable, args)
+}
+
 
 #' Computes the hinge loss between `y_true` & `y_pred`.
 #'
@@ -803,10 +850,10 @@ function (y_true, y_pred, ..., reduction = "sum_over_batch_size",
     name = "hinge")
 {
     args <- capture_args(list(y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -875,10 +922,10 @@ function (y_true, y_pred, delta = 1, ..., reduction = "sum_over_batch_size",
     name = "huber_loss")
 {
     args <- capture_args(list(y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -937,10 +984,10 @@ function (y_true, y_pred, ..., reduction = "sum_over_batch_size",
     name = "kl_divergence")
 {
     args <- capture_args(list(y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -1003,10 +1050,10 @@ function (y_true, y_pred, ..., reduction = "sum_over_batch_size",
     name = "log_cosh")
 {
     args <- capture_args(list(y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -1064,10 +1111,10 @@ function (y_true, y_pred, ..., reduction = "sum_over_batch_size",
     name = "mean_absolute_error")
 {
     args <- capture_args(list(y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -1130,10 +1177,10 @@ function (y_true, y_pred, ..., reduction = "sum_over_batch_size",
     name = "mean_absolute_percentage_error")
 {
     args <- capture_args(list(y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -1191,10 +1238,10 @@ function (y_true, y_pred, ..., reduction = "sum_over_batch_size",
     name = "mean_squared_error")
 {
     args <- capture_args(list(y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -1256,10 +1303,10 @@ function (y_true, y_pred, ..., reduction = "sum_over_batch_size",
     name = "mean_squared_logarithmic_error")
 {
     args <- capture_args(list(y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -1318,10 +1365,10 @@ function (y_true, y_pred, ..., reduction = "sum_over_batch_size",
     name = "poisson")
 {
     args <- capture_args(list(y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -1435,10 +1482,10 @@ function (y_true, y_pred, from_logits = FALSE, ignore_class = NULL,
     axis = -1L, ..., reduction = "sum_over_batch_size", name = "sparse_categorical_crossentropy")
 {
     args <- capture_args(list(ignore_class = as_integer, y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), axis = as_axis))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -1501,10 +1548,10 @@ function (y_true, y_pred, ..., reduction = "sum_over_batch_size",
     name = "squared_hinge")
 {
     args <- capture_args(list(y_true = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x), y_pred = function (x)
-    if (inherits(x, "python.builtin.object"))
+    if (is_py_object(x))
         x
     else np_array(x)))
     callable <- if (missing(y_true) && missing(y_pred))
@@ -1562,8 +1609,8 @@ py_to_r_wrapper.keras.src.losses.loss.Loss <- function(x) {
   force(x)
   as.function.default(c(formals(x), quote({
     args <- capture_args(list(y_true = as_py_array,
-                               y_pred = as_py_array,
-                               sample_weight = as_py_array))
+                              y_pred = as_py_array,
+                              sample_weight = as_py_array))
     do.call(x, args)
   })))
 }
