@@ -155,12 +155,14 @@ function(classname,
 #' @importFrom reticulate r_to_py import_builtins py_eval py_dict py_call
 #' @export
 r_to_py.R6ClassGenerator <- function(x, convert = TRUE) {
+  members <- c(x$public_fields,
+               x$public_methods,
+               lapply(x$active, active_property))
+  members$clone <- NULL
   new_py_type(
     classname = x$classname,
     inherit = x$get_inherit(),
-    members = c(x$public_fields,
-                x$public_methods,
-                lapply(x$active, active_property)),
+    members = members,
     private = c(x$private_fields,
                 x$private_methods),
     parent_env = x$parent_env
@@ -215,7 +217,7 @@ new_get_private <- function(members, shared_mask_env) {
     instance_mask_env$self <- self
     instance_mask_env$private <- private
     members <- lapply(members, function(member) {
-      if (is.function(member) && !inherits(member, "python.builtin.object"))
+      if (is.function(member) && !is_py_object(member))
         environment(member) <- instance_mask_env
       member
     })
@@ -269,7 +271,7 @@ resolve_py_type_inherits <- function(inherit, convert=FALSE) {
   names(bases) <- NULL
 
   bases <- lapply(bases, function(cls) {
-    if (!inherits(cls, "python.builtin.object"))
+    if (!is_py_object(cls))
       tryCatch(
         cls <- r_to_py(cls),
         error = function(e)
@@ -289,7 +291,7 @@ resolve_py_type_inherits <- function(inherit, convert=FALSE) {
 as_py_method <- function(fn, name, env, convert, label) {
 
     # if user did conversion, they're responsible for ensuring it is right.
-    if (inherits(fn, "python.builtin.object")) {
+    if (is_py_object(fn)) {
       #assign("convert", convert, as.environment(fn))
       return(fn)
     }
