@@ -8,11 +8,12 @@ library(keras3)
 
 files <- list.files("vignettes-src/examples",
                     pattern = "^[^_.].+\\.[RrQq]md",
+                    recursive = TRUE,
                     full.names = TRUE)
 
 # render index last
 files <- unique(c(files, grep("index", files, value = TRUE)), fromLast = TRUE)
 
 for (f in files) {
-  knit_vignette(f)
+  knit_vignette(f, external = TRUE)
 }
